@@ -9,6 +9,12 @@ class AgentTransportException(AgentException):
     """
 
 
+class BounceError(AgentTransportException):
+    """
+    Raised when the agent receives a bounce message.
+    """
+
+
 class ProvisionListDeniedError(AgentTransportException):
     """
     Raised when the backend is not able to list the provisions.
