@@ -42,6 +42,10 @@ from rekuest_next.api.schema import (
     ValidatorInput,
     my_implementation_at,
 )
+import logging
+
+
+logger = logging.getLogger(__name__)
 
 
 def interface_name(func: AnyFunction) -> str:
@@ -65,9 +69,7 @@ R = TypeVar("R")
 class WrappedFunction(Generic[P, R]):
     """A wrapped function that calls the actor's implementation."""
 
-    def __init__(
-        self, func: AnyFunction, interface: str, definition: DefinitionInput
-    ) -> None:
+    def __init__(self, func: AnyFunction, interface: str, definition: DefinitionInput) -> None:
         """Initialize the wrapped function."""
         self.func = func
         self.interface = interface
@@ -77,9 +79,7 @@ class WrappedFunction(Generic[P, R]):
     def call(self, *args: P.args, **kwargs: P.kwargs) -> R:
         """ "Call the actor's implementation."""
         helper = get_current_assignation_helper()
-        implementation = my_implementation_at(
-            helper.actor.agent.instance_id, self.interface
-        )
+        implementation = my_implementation_at(helper.actor.agent.instance_id, self.interface)
 
         return call(implementation, *args, parent=helper.assignment, **kwargs)
 
@@ -87,12 +87,20 @@ class WrappedFunction(Generic[P, R]):
         """ "Call the wrapped function directly if not within an assignation."""
         try:
             helper = get_current_assignation_helper()
-            dependency = helper.get_dependency(
-                self.interface,
-            )
+
+            try:
+                dependency = helper.get_dependency(
+                    self.interface,
+                )
+            except KeyError:
+                dependency = None  # type: ignore
+                logger.debug(
+                    "No dependency found for interface %s, but registered locally calling it directly.",
+                    self.interface,
+                )  # TODO: Figure out if we want this behavior
+                return self.func(*args, **kwargs)
 
             implementation = get_implementation(dependency)
-
             return call(implementation, *args, parent=helper.assignment, **kwargs)
         except NotWithinAnAssignationError:
             return self.func(*args, **kwargs)
@@ -190,9 +198,7 @@ def register_func(
             definition=definition,
             dependencies=tuple(
                 [
-                    x
-                    if isinstance(x, ActionDependencyInput)
-                    else x.to_dependency_input()
+                    x if isinstance(x, ActionDependencyInput) else x.to_dependency_input()
                     for x in (dependencies or [])
                 ]
             ),
@@ -441,9 +447,7 @@ def register(  # type: ignore[valid-type]
             )
 
             setattr(function_or_actor, "__definition__", definition)
-            setattr(
-                function_or_actor, "__definition_hash__", hash_definition(definition)
-            )
+            setattr(function_or_actor, "__definition_hash__", hash_definition(definition))
             setattr(
                 function_or_actor,
                 "__interface__",
